@@ -142,6 +142,7 @@ for my $pm (@pmfiles ) {
   my @bits = split /\//, $1; # split extracted on /, llast bit is basename
   $pmkeys{ $bits[-1] } = $pm ; # put the path object in the hash keyed on the basename.
 }
+FORMD:
 for my $md ( @mdfiles ) {
   my $name = $md->basename;
   $name =~ s/\.md$//;
@@ -155,6 +156,7 @@ for my $md ( @mdfiles ) {
     $pm->spew( $pmtext );
     say "updated $pm added pod from $md";
   } else {
+      next FORMD if $md =~ /README/ ;
       my $mdtext = path($md)->slurp();
       $mdtext =~ s/(\# ABSTRACT.*)\n//;
       my $abstract = $1;
