@@ -17,14 +17,14 @@ use Storable 3.15 'dclone';
 
 no warnings 'experimental';
 
-our $VERSION='0.02430';
+our $VERSION='1.00';
 
 =head1 NAME
 
 Vote::Count
 
 
-=head1 VERSION 0.02430
+=head1 VERSION 1.00
 
 =cut
 
@@ -108,7 +108,7 @@ with 'Vote::Count::Approval',
   'Vote::Count::Floor',
   'Vote::Count::IRV',
   'Vote::Count::Log',
-  'Vote::Count::Range',  
+  'Vote::Count::Range',
   'Vote::Count::TieBreaker',
   'Vote::Count::TopCount',
   ;
@@ -118,11 +118,13 @@ sub VotesCast ( $self ) {
 }
 
 sub BallotSetType ( $self ) {
-  if( $self->BallotSet()->{'options'}{'rcv'} ) {
-    return 'rcv'
-  } elsif ( $self->BallotSet()->{'options'}{'range'} ) {
-    return 'range'
-  } else {
+  if ( $self->BallotSet()->{'options'}{'rcv'} ) {
+    return 'rcv';
+  }
+  elsif ( $self->BallotSet()->{'options'}{'range'} ) {
+    return 'range';
+  }
+  else {
     die "BallotSetType is undefined or unknown type.";
   }
 }
@@ -150,7 +152,7 @@ This is also extremely useful to researchers who may want to study multiple meth
   use feature qw /postderef signatures/;
 
   use Vote::Count;
-  use Vote::Count::ReadBallots 'read_ballots';
+  use Vote::Count::ReadBallots;
   use Vote::Count::Method::CondorcetDropping;
 
   # example uses biggerset1 from the distribution test data.
@@ -242,6 +244,8 @@ Cloning occurs when similar choices are available, such as Vanilla and Vanilla B
 
 The cases described above: Monotonocity, Independence of Irrelevant Alternatives and Clone Independence are normally discussed as seperate criteria rather than components of one. Additional sub-criteria that haven't been mentioned include: Reversal Symmetry, Participation Consistency, and Later No Help (which could also be considered a sub-criteria of Later Harm).
 
+There is a specific Criteria that is sometimes called Consistency, in this discussion consistency is discussed in the broad context. No method passes every possible consistency criteria, from a policy perspective a method is consistent if it has no major consistency failures.
+
 
 =head4 Complexity
 
@@ -342,19 +346,23 @@ The basic Condorcet Method will frequently fail to identify a winner. One possib
 Complexity Varies among sub-methods.
 
 
+
 =item *
 
 Fails Later Harm.
 
 
+
 =item *
 
 Meets both Condorcet Criteria.
 
 
+
 =item *
 
-When a Condorcet Winner is present Consistency is met. When there is no Condorcet Winner this Consistency applies between a Dominant (Smith) Set and the rest of the choices, but not within the Smith Set. Sub-methods vary in consistency when there is no Condorcet Winner.
+When a Condorcet Winner is present Consistency is very high. When there is no Condorcet Winner this Consistency applies between a Dominant (Smith) Set and the rest of the choices, but not within the Smith Set. Sub-methods vary in consistency when there is no Condorcet Winner.
+
 
 
 =back
@@ -632,7 +640,7 @@ L<Vote::Count::Start|https://metacpan.org/pod/Vote::Count::Start>
 
 =head1 Call for Contributions
 
-This project needs contributions from Programmers and Mathematicians. Review and citations from Mathematicians are urgently requested, because in addition to being a Tool-set for implementing vote counting this documentation will for many also be the manual. From coders there is a lot of help that could be given: any well known method could use a write up if it is easy to implement with the toolkit (see Benham) or a code submission if it is not. Currently Tiedeman, SSD, and Kemmeny-Young are unimplemented. In addition support for Range Ballots will require significant effort.
+This project needs contributions from Programmers and Mathematicians. Review and citations from Mathematicians are urgently requested, because in addition to being a Tool-set for implementing vote counting this documentation will for many also be the manual. From coders there is a lot of help that could be given: any well known method could use a write up if it is easy to implement with the toolkit (see Benham) or a code submission if it is not. Currently Tiedeman, SSD, and Kemmeny-Young are unimplemented.
 
 
 =head1 Advice, Recommendations, Opinion
@@ -651,11 +659,11 @@ I<Smith Set IRV> meets all three key criteria for Condorcet Methods and has less
 
 If you like I<Borda> or prefer a I<Range Ballot>, my pick is for I<STAR>.
 
-STAR is handcountable but requires a Range Ballot. Range methods like STAR have considerably less Later Harm effect than other Borda Methods.
+STAR is handcountable but requires a Range Ballot. Range methods like STAR have less Later Harm effect than Borda Methods.
 
 I<Redacting Condorcet Methods> are the B<best> for a conventional Ranked Choice Ballot. If a Condorcet Winner does not create a Later Harm violation they will always be chosen. They can create a gauge of the later harm effect that then allows for the establishment of a Later Harm tolerance. The steps for I<Condorcet Vs IRV> are easy to understand but the number of steps qualifies it as somewhat complex. Other methods in the family (not yet implemented) will be more complex.
 
-B<STAR> and B<Redacting Condorcet> (Condorcet Vs IRV being the only one available here at the moment) are my preference. If you need to hand count, Benham is your Condorcet Method and IRV is your Later Harm Protected Method. Smith Set IRV is a middle ground. If Later Harm compliance is required a Redacting Condorcet Method is your best choice, and IRV your choice if they're too complex.
+B<STAR> and B<Redacting Condorcet> (Condorcet Vs IRV being the only one available here at the moment) are my preference. If you need to hand count, Benham is your Condorcet Method and IRV is your Later Harm Protected Method. Smith Set IRV is a simple Condorcet Method that is better on Later Harm than any other non-redacting Condorcer Method, it is a much better choice than Benham. If Later Harm compliance is required a Redacting Condorcet Method is your best choice, and IRV your choice if they're too complex.
 
 
 =head2 Floor Rules and Tie Breakers
